TextMap

Struct TextMap 

pub struct TextMap {
    pub nodes: Vec<TextNode>,
    pub title: String,
}
Available on crate feature text-map only.
Result of extract_text_nodes: an ordered list of content text nodes with the page title.

Pass nodes (or a subset) to replace_text_nodes to rewrite the HTML while keeping all markup intact.

Example

let map = webshift::extract_text_nodes("<p>Hello <strong>world</strong></p>");
assert_eq!(map.nodes[0].text, "Hello");
assert_eq!(map.nodes[1].text, "world");

Fields

nodes: Vec<TextNode>

Ordered list of text nodes found outside noise elements (<script>, <style>, <nav>, <footer>, <header>, <aside>, <form>, <iframe>, <noscript>, <svg>, <button>, <input>, <select>, <textarea>, <head>).

title: String

Page title extracted from <title>, or an empty string if absent.